@@ -50,7 +50,14 @@ class Alias(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Alias.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["AliasProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -76,7 +83,13 @@ class AliasProps:
         :param key_id: Property keyId: Globally unique identifier of the CMK.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AliasProps.__init__)
+            def stub(
+                *,
+                alias_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                key_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alias_name", value=alias_name, expected_type=type_hints["alias_name"])
             check_type(argname="argument key_id", value=key_id, expected_type=type_hints["key_id"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -139,7 +152,14 @@ class Key(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Key.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Optional[typing.Union["KeyProps", typing.Dict[str, typing.Any]]] = None,
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -192,7 +212,19 @@ class KeyProps:
         :param rotation_interval: Property rotationInterval: The time period for automatic rotation. The format is integer[unit], where integer represents the length of time and unit represents the time unit. The legal unit units are: d (day), h (hour), m (minute), s (second). 7d or 604800s both represent a 7-day cycle. Value: 7~730 days.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KeyProps.__init__)
+            def stub(
+                *,
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                enable: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                enable_automatic_rotation: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                key_spec: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                key_usage: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                pending_window_in_days: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                protection_level: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                rotation_interval: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
             check_type(argname="argument enable_automatic_rotation", value=enable_automatic_rotation, expected_type=type_hints["enable_automatic_rotation"])
@@ -343,7 +375,14 @@ class RosAlias(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosAlias.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosAliasProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -359,7 +398,9 @@ class RosAlias(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosAlias._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -388,7 +429,11 @@ class RosAlias(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosAlias, "alias_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "aliasName", value)
 
@@ -401,7 +446,9 @@ class RosAlias(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosAlias, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -419,7 +466,11 @@ class RosAlias(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosAlias, "key_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keyId", value)
 
@@ -442,7 +493,13 @@ class RosAliasProps:
         :param key_id: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosAliasProps.__init__)
+            def stub(
+                *,
+                alias_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                key_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alias_name", value=alias_name, expected_type=type_hints["alias_name"])
             check_type(argname="argument key_id", value=key_id, expected_type=type_hints["key_id"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -502,7 +559,14 @@ class RosKey(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosKey.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosKeyProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -518,7 +582,9 @@ class RosKey(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosKey._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -549,7 +615,9 @@ class RosKey(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -569,7 +637,11 @@ class RosKey(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "description").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -589,7 +661,11 @@ class RosKey(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "enable").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enable", value)
 
@@ -609,7 +685,11 @@ class RosKey(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "enable_automatic_rotation").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableAutomaticRotation", value)
 
@@ -629,7 +709,11 @@ class RosKey(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "key_spec").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keySpec", value)
 
@@ -649,7 +733,11 @@ class RosKey(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "key_usage").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "keyUsage", value)
 
@@ -669,7 +757,11 @@ class RosKey(
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "pending_window_in_days").fset)
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pendingWindowInDays", value)
 
@@ -693,7 +785,11 @@ class RosKey(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "protection_level").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "protectionLevel", value)
 
@@ -713,7 +809,11 @@ class RosKey(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosKey, "rotation_interval").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "rotationInterval", value)
 
@@ -757,7 +857,19 @@ class RosKeyProps:
         :param rotation_interval: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosKeyProps.__init__)
+            def stub(
+                *,
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                enable: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                enable_automatic_rotation: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                key_spec: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                key_usage: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                pending_window_in_days: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                protection_level: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                rotation_interval: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
             check_type(argname="argument enable_automatic_rotation", value=enable_automatic_rotation, expected_type=type_hints["enable_automatic_rotation"])
@@ -902,7 +1014,14 @@ class RosSecret(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosSecret.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosSecretProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -918,7 +1037,9 @@ class RosSecret(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosSecret._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -957,7 +1078,9 @@ class RosSecret(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -978,7 +1101,11 @@ class RosSecret(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "secret_data").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretData", value)
 
@@ -996,7 +1123,11 @@ class RosSecret(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "secret_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretName", value)
 
@@ -1017,7 +1148,11 @@ class RosSecret(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "version_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "versionId", value)
 
@@ -1037,7 +1172,11 @@ class RosSecret(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "description").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -1062,7 +1201,11 @@ class RosSecret(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "encryption_key_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "encryptionKeyId", value)
 
@@ -1086,7 +1229,11 @@ class RosSecret(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "force_delete_without_recovery").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "forceDeleteWithoutRecovery", value)
 
@@ -1106,7 +1253,11 @@ class RosSecret(
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "recovery_window_in_days").fset)
+            def stub(
+                value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "recoveryWindowInDays", value)
 
@@ -1130,7 +1281,11 @@ class RosSecret(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "secret_data_type").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secretDataType", value)
 
@@ -1150,7 +1305,11 @@ class RosSecret(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosSecret, "version_stages").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "versionStages", value)
 
@@ -1197,7 +1356,20 @@ class RosSecretProps:
         :param version_stages: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosSecretProps.__init__)
+            def stub(
+                *,
+                secret_data: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                secret_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                version_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                encryption_key_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                force_delete_without_recovery: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                recovery_window_in_days: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                secret_data_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                version_stages: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument secret_data", value=secret_data, expected_type=type_hints["secret_data"])
             check_type(argname="argument secret_name", value=secret_name, expected_type=type_hints["secret_name"])
             check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
@@ -1369,7 +1541,14 @@ class Secret(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Secret.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["SecretProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1431,7 +1610,20 @@ class SecretProps:
         :param version_stages: Property versionStages: The stage labels that mark the secret version. ACSCurrent will be marked as DefaultIf you do not specify it, Secrets Manager marks it with "ACSCurrent".
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SecretProps.__init__)
+            def stub(
+                *,
+                secret_data: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                secret_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                version_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                encryption_key_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                force_delete_without_recovery: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                recovery_window_in_days: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+                secret_data_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                version_stages: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[builtins.str, ros_cdk_core.IResolvable]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument secret_data", value=secret_data, expected_type=type_hints["secret_data"])
             check_type(argname="argument secret_name", value=secret_name, expected_type=type_hints["secret_name"])
             check_type(argname="argument version_id", value=version_id, expected_type=type_hints["version_id"])
